@@ -83,7 +83,7 @@ class Metadata(Entity):
 
         Returns
         -------
-        :class:`~labstep.metadata.Metadata`
+        :class:`~labstep.entities.metadata.model.Metadata`
             An object representing the edited Metadata.
 
         Example
