@@ -7,15 +7,9 @@ from labstep.generic.entity.repository import entityRepository
 
 
 class ShareLinkRepository:
-    def newSharelink(self, user, fields):
-        return entityRepository.newEntity(user, Sharelink, fields)
-
     def getSharelink(self, entity):
         key = entity.__entityName__.replace("-", "_") + "_id"
-        if entity.share_link is None:
-            return self.newSharelink(entity.__user__, fields={key: entity.id})
-
-        return Sharelink(entity.share_link, entity.__user__)
+        return entityRepository.newEntity(entity.__user__, Sharelink, fields={key: entity.id})
 
 
 shareLinkRepository = ShareLinkRepository()
