@@ -2,11 +2,10 @@
 # -*- coding: utf-8 -*-
 # Author: Barney Walker <barney@labstep.com>
 
-import json
-import urllib.parse
+from deprecated import deprecated
 from labstep.generic.entity.model import Entity
 from labstep.service.config import API_ROOT
-from labstep.service.helpers import url_join, handleError, getHeaders
+from labstep.service.helpers import url_join, getHeaders
 from labstep.service.request import requestService
 
 
@@ -641,44 +640,9 @@ class User(Entity):
             self, count=count, search_query=search_query, extraParams=extraParams
         )
 
+    @deprecated(version='3.0.3', reason="You should use workspace.getFiles instead")
     def getFiles(self, count=100, search_query=None, file_type=None, extraParams={}):
-        """
-        Retrieve a list of a User's Files
-        across all Workspaces on Labstep,
-        which can be filtered using the parameters:
-
-        Parameters
-        ----------
-        count (int)
-            The number of files to retrieve.
-        file_type (str)
-            Return only files of a certain type. Options are:
-            'csv', 'doc',
-            'docx', 'jpg', 'pdf','png','ppt','pptx','svg','xls','xlsx',
-            'xml' or 'generic' for all others.
-        search_query (str)
-            Search for files with this name.
-
-        Returns
-        -------
-        List[:class:`~labstep.entities.file.model.File`]
-            A list of Labstep Files.
-
-        Example
-        -------
-        ::
-
-            entities = user.getFiles(search_query='bacteria')
-        """
-        from labstep.entities.file.repository import fileRepository
-
-        return fileRepository.getFiles(
-            self,
-            count=count,
-            search_query=search_query,
-            file_type=file_type,
-            extraParams=extraParams,
-        )
+        return []
 
     def getDevices(self, count=100, search_query=None, extraParams={}):
         """
@@ -929,7 +893,7 @@ class User(Entity):
 
         return workspaceRepository.newWorkspace(self, name, extraParams=extraParams)
 
-    def newFile(self, filepath, extraParams={}):
+    def newFile(self, filepath, rawData=None, extraParams={}):
         """
         Upload a file to the Labstep entity Data.
 
@@ -946,7 +910,7 @@ class User(Entity):
         """
         from labstep.entities.file.repository import fileRepository
 
-        return fileRepository.newFile(self, filepath, extraParams=extraParams)
+        return fileRepository.newFile(self, filepath, rawData=rawData, extraParams=extraParams)
 
     def newCollection(self, name, type="experiment"):
         """
