@@ -599,6 +599,7 @@ class Workspace(Entity):
 
             workspace.setAutosharing(experiment_sharing='view')
         """
+        self.update()
 
         if self.security_policy is None:
             from labstep.generic.entity.repository import entityRepository
@@ -606,7 +607,7 @@ class Workspace(Entity):
             policy = entityRepository.newEntity(
                 self.__user__,
                 Autoshare,
-                {"user_group": self.logged_user_user_group["id"]},
+                {"user_group_id": self.logged_user_user_group["id"]},
             )
         else:
             policy = Autoshare(self.security_policy, self.__user__)
