@@ -3,6 +3,7 @@
 # Author: Barney Walker <barney@labstep.com>
 
 import json
+from pathlib import Path
 from labstep.service.config import API_ROOT
 from labstep.service.helpers import (
     listToClass,
@@ -15,7 +16,8 @@ from labstep.service.request import requestService
 class EntityRepository:
     def getLegacyEntity(self, user, entityClass, id):
         headers = getHeaders(user)
-        url = url_join(API_ROOT, "/api/generic/", entityClass.__entityName__, str(id))
+        url = url_join(API_ROOT, "/api/generic/",
+                       entityClass.__entityName__, str(id))
         response = requestService.get(url, headers=headers)
         return entityClass(json.loads(response.content), user)
 
@@ -25,7 +27,8 @@ class EntityRepository:
         else:
             params = {"is_deleted": isDeleted, "get_single": 1, "id": id}
             headers = getHeaders(user)
-            url = url_join(API_ROOT, "/api/generic/", entityClass.__entityName__)
+            url = url_join(API_ROOT, "/api/generic/",
+                           entityClass.__entityName__)
             response = requestService.get(url, headers=headers, params=params)
             return entityClass(json.loads(response.content), user)
 
@@ -51,7 +54,8 @@ class EntityRepository:
     def newEntity(self, user, entityClass, fields):
         headers = getHeaders(user)
         url = url_join(API_ROOT, "/api/generic/", entityClass.__entityName__)
-        fields = dict(filter(lambda field: field[1] is not None, fields.items()))
+        fields = dict(
+            filter(lambda field: field[1] is not None, fields.items()))
 
         if "group_id" not in fields and getattr(
             entityClass, "__hasParentGroup__", False
@@ -63,8 +67,10 @@ class EntityRepository:
 
     def newEntities(self, user, entityClass, items):
         headers = getHeaders(user)
-        url = url_join(API_ROOT, "/api/generic/", entityClass.__entityName__, "batch")
-        response = requestService.post(url, headers=headers, json={"items": items})
+        url = url_join(API_ROOT, "/api/generic/",
+                       entityClass.__entityName__, "batch")
+        response = requestService.post(
+            url, headers=headers, json={"items": items})
         entities = json.loads(response.content)
         return list(map(lambda entity: entityClass(entity, user), entities))
 
@@ -72,12 +78,39 @@ class EntityRepository:
         # Filter the 'fields' dictionary by removing {'fields': None}
         # to preserve the existing data in the 'fields', otherwise
         # the 'fields' will be overwritten to 'None'.
-        newFields = dict(filter(lambda field: field[1] is not None, fields.items()))
+        newFields = dict(
+            filter(lambda field: field[1] is not None, fields.items()))
         headers = getHeaders(entity.__user__)
-        url = url_join(API_ROOT, "/api/generic/", entity.__entityName__, str(entity.id))
+        url = url_join(API_ROOT, "/api/generic/",
+                       entity.__entityName__, str(entity.id))
         response = requestService.put(url, json=newFields, headers=headers)
         entity.__init__(json.loads(response.content), entity.__user__)
         return entity
 
+    def exportEntity(self, entity, rootPath):
+        from labstep.entities.file.model import File
+
+        entityDir = Path(rootPath).joinpath(
+            f'{entity.id}')
+        entityDir.mkdir(parents=True, exist_ok=True)
+        infoFile = entityDir.joinpath('entity.json')
+
+        with open(infoFile, 'w') as out:
+            json.dump(entity.__data__, out, indent=2)
+
+        if hasattr(entity, 'file') and entity.file is not None:
+            lsFile = entity.file
+            fileDir = entityDir.joinpath(f'files/{str(lsFile["id"])}')
+            fileDir.mkdir(parents=True, exist_ok=True)
+            File(lsFile, entity.__user__).save(fileDir)
+
+        if hasattr(entity, 'files') and entity.files is not None:
+            for lsFile in entity.files:
+                fileDir = entityDir.joinpath(f'files/{str(lsFile["id"])}')
+                fileDir.mkdir(parents=True, exist_ok=True)
+                File(lsFile, entity.__user__).save(fileDir)
+
+        return entityDir
+
 
 entityRepository = EntityRepository()
